==> ponyc-0.21.2-1-x86_64.pkg.tar.xz: usr/share/doc/pony/stdlib-docs/docs/cli-Option.md <==
# Option

Option contains a spec and an effective value for a given option.


```pony
class val Option
```

## Constructors

### create

```pony
new val create(
  spec': OptionSpec val,
  value': (Bool val | String val | I64 val | 
    F64 val | _StringSeq val))
: Option val^
```
#### Parameters

*   spec': [OptionSpec](cli-OptionSpec) val
*   value': ([Bool](builtin-Bool) val | [String](builtin-String) val | [I64](builtin-I64) val | 
    [F64](builtin-F64) val | [_StringSeq](cli-_StringSeq) val)

#### Returns

* [Option](cli-Option) val^

---

## Public Functions

### spec

```pony
fun box spec()
: OptionSpec val
```

#### Returns

* [OptionSpec](cli-OptionSpec) val

---

### bool

Returns the option value as a Bool, defaulting to false.


```pony
fun box bool()
: Bool val
```

#### Returns

* [Bool](builtin-Bool) val

---

### string

Returns the option value as a String, defaulting to empty.


```pony
fun box string()
: String val
```

#### Returns

* [String](builtin-String) val

---

### i64

Returns the option value as an I64, defaulting to 0.


```pony
fun box i64()
: I64 val
```

#### Returns

* [I64](builtin-I64) val

---

### f64

Returns the option value as an F64, defaulting to 0.0.


```pony
fun box f64()
: F64 val
```

#### Returns

* [F64](builtin-F64) val

---

### string_seq

Returns the option value as a ReadSeq[String], defaulting to empty.


```pony
fun box string_seq()
: ReadSeq[String val] val
```

#### Returns

* [ReadSeq](builtin-ReadSeq)\[[String](builtin-String) val\] val

---

### deb_string

```pony
fun box deb_string()
: String val
```

#### Returns

* [String](builtin-String) val

---

## Private Functions

### _append

```pony
fun box _append(
  next: Option val)
: Option val
```
#### Parameters

*   next: [Option](cli-Option) val

#### Returns

* [Option](cli-Option) val

---

==> ponyc-0.23.0-1-x86_64.pkg.tar.xz: usr/share/doc/pony/stdlib-docs/docs/cli-Option.md <==
# Option
<span class="source-link">[[Source]](src/cli/command.md#L63)</span>

Option contains a spec and an effective value for a given option.


```pony
class val Option
```

## Constructors

### create
<span class="source-link">[[Source]](src/cli/command.md#L70)</span>


```pony
new val create(
  spec': OptionSpec val,
  value': (Bool val | String val | I64 val | 
    U64 val | F64 val | _StringSeq val))
: Option val^
```
#### Parameters

*   spec': [OptionSpec](cli-OptionSpec) val
*   value': ([Bool](builtin-Bool) val | [String](builtin-String) val | [I64](builtin-I64) val | 
    [U64](builtin-U64) val | [F64](builtin-F64) val | [_StringSeq](cli-_StringSeq) val)

#### Returns

* [Option](cli-Option) val^

---

## Public Functions

### spec
<span class="source-link">[[Source]](src/cli/command.md#L77)</span>


```pony
fun box spec()
: OptionSpec val
```

#### Returns

* [OptionSpec](cli-OptionSpec) val

---

### bool
<span class="source-link">[[Source]](src/cli/command.md#L79)</span>


Returns the option value as a Bool, defaulting to false.


```pony
fun box bool()
: Bool val
```

#### Returns

* [Bool](builtin-Bool) val

---

### string
<span class="source-link">[[Source]](src/cli/command.md#L85)</span>


Returns the option value as a String, defaulting to empty.


```pony
fun box string()
: String val
```

#### Returns

* [String](builtin-String) val

---

### i64
<span class="source-link">[[Source]](src/cli/command.md#L91)</span>


Returns the option value as an I64, defaulting to 0.


```pony
fun box i64()
: I64 val
```

#### Returns

* [I64](builtin-I64) val

---

### u64
<span class="source-link">[[Source]](src/cli/command.md#L97)</span>


Returns the option value as an U64, defaulting to 0.


```pony
fun box u64()
: U64 val
```

#### Returns

* [U64](builtin-U64) val

---

### f64
<span class="source-link">[[Source]](src/cli/command.md#L103)</span>


Returns the option value as an F64, defaulting to 0.0.


```pony
fun box f64()
: F64 val
```

#### Returns

* [F64](builtin-F64) val

---

### string_seq
<span class="source-link">[[Source]](src/cli/command.md#L109)</span>


Returns the option value as a ReadSeq[String], defaulting to empty.


```pony
fun box string_seq()
: ReadSeq[String val] val
```

#### Returns

* [ReadSeq](builtin-ReadSeq)\[[String](builtin-String) val\] val

---

### deb_string
<span class="source-link">[[Source]](src/cli/command.md#L119)</span>


```pony
fun box deb_string()
: String val
```

#### Returns

* [String](builtin-String) val

---

## Private Functions

### _append
<span class="source-link">[[Source]](src/cli/command.md#L74)</span>


```pony
fun box _append(
  next: Option val)
: Option val
```
#### Parameters

*   next: [Option](cli-Option) val

#### Returns

* [Option](cli-Option) val

---
